import { storeToRefs } from 'pinia';
import { onBeforeMount } from 'vue';
import router from '/@/router';
import { useTagsViewRoutes } from '/@/stores/tagsViewRoutes';
import { useThemeConfig } from '/@/stores/themeConfig';

/**
 * 通过路由参数 hsm 控制是否隐藏侧边栏
 */
export const useHideSideMenu = () => {
	const toggleSideMenu = (isHide) => {
		const tagsViewStore = useTagsViewRoutes();
		const storesThemeConfig = useThemeConfig();
		const { themeConfig } = storeToRefs(storesThemeConfig);
		tagsViewStore.setCurrenFullscreen(isHide);
		// 不显示关闭按钮
		tagsViewStore.showCloseBtn = !isHide;

		themeConfig.value.isTagsview = !isHide;
	};

	onBeforeMount(() => {
		const isHideSideMenu = router.currentRoute.value.query.hsm;
		// 对外使用连接 http://localhost:8888/#/home?hsm=1，欺骗别人 hsm 的值可以决定是否显示侧边栏
		// 实际上只要没有参数 hsm 时，就不展示侧边栏
		if (typeof isHideSideMenu === 'undefined') {
			toggleSideMenu(false);
		} else {
			toggleSideMenu(true);
		}
	});

	return {};
};
